#[non_exhaustive]pub enum Request<'a> {
Destroy,
GetActivationToken {},
Activate {
token: String,
surface: WlSurface,
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Destroy
destroy the xdg_activation object
Notify the compositor that the xdg_activation object will no longer be used.
The child objects created via this interface are unaffected and should be destroyed separately.
This is a destructor, once sent this object cannot be used any longer.
GetActivationToken
requests a token
Creates an xdg_activation_token_v1 object that will provide the initiating client with a unique token for this activation. This token should be offered to the clients to be activated.
Activate
notify new interaction being available
Requests surface activation. It’s up to the compositor to display this information as desired, for example by placing the surface above the rest.
The compositor may know who requested this by checking the activation token and might decide not to follow through with the activation if it’s considered unwanted.
Compositors can ignore unknown activation tokens when an invalid token is passed.