pub struct XdgActivationV1 { /* private fields */ }Expand description
interface for activating surfaces
A global interface used for informing the compositor about applications being activated or started, or for applications to request to be activated.
This interface has no events.
Implementations
Sourceimpl XdgActivationV1
impl XdgActivationV1
Sourcepub fn destroy(&self)
pub fn destroy(&self)
destroy the xdg_activation object
Notify the compositor that the xdg_activation object will no longer be used.
The child objects created via this interface are unaffected and should be destroyed separately.
Sourcepub fn get_activation_token<U, D: 'static>(
&self,
qh: &QueueHandle<D>,
udata: U,
) -> XdgActivationTokenV1
pub fn get_activation_token<U, D: 'static>( &self, qh: &QueueHandle<D>, udata: U, ) -> XdgActivationTokenV1
requests a token
Creates an xdg_activation_token_v1 object that will provide the initiating client with a unique token for this activation. This token should be offered to the clients to be activated.
Sourcepub fn activate(&self, token: String, surface: &WlSurface)
pub fn activate(&self, token: String, surface: &WlSurface)
notify new interaction being available
Requests surface activation. It’s up to the compositor to display this information as desired, for example by placing the surface above the rest.
The compositor may know who requested this by checking the activation token and might decide not to follow through with the activation if it’s considered unwanted.
Compositors can ignore unknown activation tokens when an invalid token is passed.